@@ -14,8 +14,8 @@
  * When to use:	Methods communicating to asterisk about module initialization, status, destruction
  * Relations:	Main hub for all other sourcefiles.
  *
- * $Date: 2014-06-22 12:58:33 +0200 (Sun, 22 Jun 2014) $
- * $Revision: 5502 $
+ * $Date: 2014-07-04 12:59:07 +0200 (Fri, 04 Jul 2014) $
+ * $Revision: 5574 $
  */
 
 #include <config.h>
@@ -48,7 +48,7 @@
 #include "revision.h"
 #include <signal.h>
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 5502 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5574 $")
 
 #define ENUMMACRO_FILE "chan_sccp_enums.hh"
 #define ENUMMACRO_GENERATE ENUMMACRO_GENFUNCTION
@@ -589,7 +589,7 @@ boolean_t sccp_prePBXLoad(void)
 	GLOB(video_cos) = 5;
 	GLOB(echocancel) = TRUE;
 	GLOB(silencesuppression) = TRUE;
-	GLOB(dndmode) = SCCP_DNDMODE_REJECT;
+	GLOB(dndFeature) = TRUE;
 	GLOB(autoanswer_tone) = SKINNY_TONE_ZIP;
 	GLOB(remotehangup_tone) = SKINNY_TONE_ZIP;
 	GLOB(callwaiting_tone) = SKINNY_TONE_CALLWAITINGTONE;
@@ -597,7 +597,7 @@ boolean_t sccp_prePBXLoad(void)
 	GLOB(mwilamp) = SKINNY_LAMP_ON;
 	GLOB(protocolversion) = SCCP_DRIVER_SUPPORTED_PROTOCOL_HIGH;
 	GLOB(amaflags) = pbx_channel_string2amaflag("documentation");
-	GLOB(callanswerorder) = ANSWER_OLDEST_FIRST;
+	GLOB(callanswerorder) = SCCP_ANSWER_OLDEST_FIRST;
 	GLOB(socket_thread) = AST_PTHREADT_NULL;
 	GLOB(earlyrtp) = SCCP_EARLYRTP_PROGRESS;
 	sccp_create_hotline();
