@@ -9,8 +9,8 @@
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *		See the LICENSE file at the top of the source tree.
  *
- * $Date: 2014-06-24 13:32:51 +0200 (Tue, 24 Jun 2014) $
- * $Revision: 5513 $  
+ * $Date: 2014-07-02 19:35:43 +0200 (Wed, 02 Jul 2014) $
+ * $Revision: 5559 $  
  */
 #include <config.h>
 #include "../../common.h"
@@ -21,7 +21,7 @@
 #include "../../sccp_socket.h"
 #include "../../sccp_pbx.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 5513 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5559 $")
 
 /*
  * \brief itterate through locked pbx channels
@@ -54,7 +54,7 @@ PBX_CHANNEL_TYPE *pbx_channel_walk_locked(PBX_CHANNEL_TYPE * target)
 
 	if (tmp) {
 		res = tmp;
-		tmp = ast_channel_unref(tmp);
+		tmp = pbx_channel_unref(tmp);
 		ast_channel_lock(res);
 	}
 	ast_channel_iterator_destroy(iter);
@@ -88,7 +88,7 @@ PBX_CHANNEL_TYPE *pbx_channel_search_locked(int (*is_match) (PBX_CHANNEL_TYPE *,
 		return NULL;
 	}
 
-	for (; iter && (tmp = ast_channel_iterator_next(iter)); tmp = ast_channel_unref(tmp)) {
+	for (; iter && (tmp = ast_channel_iterator_next(iter)); tmp = pbx_channel_unref(tmp)) {
 		pbx_channel_lock(tmp);
 		if (is_match(tmp, data)) {
 			matched = TRUE;
@@ -103,7 +103,7 @@ PBX_CHANNEL_TYPE *pbx_channel_search_locked(int (*is_match) (PBX_CHANNEL_TYPE *,
 
 	if (matched) {
 		pbx_channel = tmp;
-		tmp = ast_channel_unref(tmp);
+		tmp = pbx_channel_unref(tmp);
 		return pbx_channel;
 	} else {
 		return NULL;
@@ -430,69 +430,105 @@ sccp_channel_t *get_sccp_channel_from_pbx_channel(const PBX_CHANNEL_TYPE * pbx_c
 	}
 }
 
-static boolean_t sccp_wrapper_asterisk_nullHangup(sccp_channel_t *channel)
-{
-	return FALSE;
-}
+//static boolean_t sccp_wrapper_asterisk_nullHangup(sccp_channel_t *channel)
+//{
+//	return FALSE;
+//}
 
-static boolean_t sccp_wrapper_asterisk_carefullHangup(sccp_channel_t *channel)
+static boolean_t sccp_wrapper_asterisk_carefullHangup(sccp_channel_t *c)
 {
 	boolean_t res = FALSE;
-	if (!channel || !channel->owner) {
+	if (!c || !c->owner) {
 		return FALSE;
 	}
-	PBX_CHANNEL_TYPE *pbx_channel = ast_channel_ref(channel->owner);
+	AUTO_RELEASE sccp_channel_t *channel = sccp_channel_retain(c);
+	if (channel && channel->owner) {
+		PBX_CHANNEL_TYPE *pbx_channel = pbx_channel_ref(channel->owner);
 
-	/* let's wait for a bit, for the dust to settle */
-	sched_yield();
-	pbx_safe_sleep(pbx_channel, 10000);
+		sccp_channel_stop_and_deny_scheduled_tasks(channel);
 
-	/* recheck everything before going forward */
-	pbx_log(LOG_NOTICE, "%s: (sccp_wrapper_asterisk_carefullHangup) processing hangup request, using carefull version. Standby.\n", pbx_channel_name(pbx_channel));
-	if (!ast_check_hangup(pbx_channel)) {
-		pbx_log(LOG_NOTICE, "%s: (sccp_wrapper_asterisk_carefullHangup) Channel still active.\n", pbx_channel_name(pbx_channel));
-		if (!pbx_test_flag(pbx_channel_flags(pbx_channel), AST_FLAG_IN_AUTOLOOP) && !pbx_channel_pbx(pbx_channel)) {
-			pbx_log(LOG_NOTICE, "%s: (sccp_wrapper_asterisk_carefullHangup) Has no PBX -> ast_hangup.\n", pbx_channel_name(pbx_channel));
+		/* let's wait for a bit, for the dust to settle */
+		sched_yield();
+		pbx_safe_sleep(pbx_channel, 1000);
+
+		/* recheck everything before going forward */
+		pbx_log(LOG_NOTICE, "%s: (sccp_wrapper_asterisk_carefullHangup) processing hangup request, using carefull version. Standby.\n", pbx_channel_name(pbx_channel));
+		if (!pbx_check_hangup(pbx_channel)) {
+			pbx_log(LOG_NOTICE, "%s: (sccp_wrapper_asterisk_carefullHangup) Channel still active.\n", pbx_channel_name(pbx_channel));
+//			if (!pbx_test_flag(pbx_channel_flags(pbx_channel), AST_FLAG_IN_AUTOLOOP) && !pbx_channel_pbx(pbx_channel)) {
+//				pbx_log(LOG_NOTICE, "%s: (sccp_wrapper_asterisk_carefullHangup) Has no PBX -> ast_hangup.\n", pbx_channel_name(pbx_channel));
+//				ast_hangup(pbx_channel);
+//				res = TRUE;
+//			} else {
+//				pbx_log(LOG_NOTICE, "%s: (sccp_wrapper_asterisk_carefullHangup) Has PBX -> ast_queue_hangup.\n", pbx_channel_name(pbx_channel));
+//				res = ast_queue_hangup(pbx_channel) ? FALSE : TRUE;
+//			}
+			if (pbx_channel_pbx(pbx_channel) || (pbx_test_flag(pbx_channel_flags(pbx_channel), AST_FLAG_BLOCKING) == 0) || pbx_channel_state(pbx_channel) == AST_STATE_UP) {
+				pbx_log(LOG_NOTICE, "%s: (sccp_wrapper_asterisk_carefullHangup) Has PBX -> ast_queue_hangup.\n", pbx_channel_name(pbx_channel));
+				res = ast_queue_hangup(pbx_channel) ? FALSE : TRUE;
+			} else {
+				pbx_log(LOG_NOTICE, "%s: (sccp_wrapper_asterisk_carefullHangup) Has no PBX -> ast_hangup.\n", pbx_channel_name(pbx_channel));
+				ast_hangup(pbx_channel);
+				res = TRUE;
+			}
+		} else {
+			pbx_log(LOG_NOTICE, "%s: (sccp_wrapper_asterisk_carefullHangup) Already Hungup. Forcing SCCP Remove Call.\n", pbx_channel_name(pbx_channel));
+			AUTO_RELEASE sccp_device_t *d = sccp_channel_getDevice_retained(channel);
+			if (d) {
+				sccp_indicate(d, channel, SCCP_CHANNELSTATE_ONHOOK);
+			}
+			res = TRUE; 
+		}
+		pbx_channel_unref(pbx_channel);
+	}
+	return res;
+}
+
+boolean_t sccp_wrapper_asterisk_requestQueueHangup(sccp_channel_t *c)
+{
+	boolean_t res = FALSE;
+	AUTO_RELEASE sccp_channel_t *channel = sccp_channel_retain(c);
+	if (channel) {
+		PBX_CHANNEL_TYPE *pbx_channel = channel->owner;
+
+		sccp_channel_stop_and_deny_scheduled_tasks(channel);
+
+		channel->hangupRequest = sccp_wrapper_asterisk_carefullHangup;
+		if (!pbx_check_hangup(pbx_channel)) {							/* if channel is not already been hungup */
+			res = ast_queue_hangup(pbx_channel) ? FALSE : TRUE;
+		} else {
+			pbx_log(LOG_NOTICE, "%s: (sccp_wrapper_asterisk_requestQueueHangup) Already Hungup\n", channel->designator);
+			AUTO_RELEASE sccp_device_t *d = sccp_channel_getDevice_retained(channel);
+			if (d) {
+				sccp_indicate(d, channel, SCCP_CHANNELSTATE_ONHOOK);
+			}
+		}
+	}
+	return res;
+}
+
+boolean_t sccp_wrapper_asterisk_requestHangup(sccp_channel_t *c)
+{
+	boolean_t res = FALSE;
+	AUTO_RELEASE sccp_channel_t *channel = sccp_channel_retain(c);
+	if (channel) {
+		PBX_CHANNEL_TYPE *pbx_channel = channel->owner;
+		sccp_channel_stop_and_deny_scheduled_tasks(channel);
+
+		channel->hangupRequest = sccp_wrapper_asterisk_carefullHangup;
+		if (!pbx_check_hangup(pbx_channel)) {
 			ast_hangup(pbx_channel);
 			res = TRUE;
 		} else {
-			pbx_log(LOG_NOTICE, "%s: (sccp_wrapper_asterisk_carefullHangup) Has PBX -> ast_queue_hangup.\n", pbx_channel_name(pbx_channel));
-			res = ast_queue_hangup(pbx_channel) ? FALSE : TRUE;
+			AUTO_RELEASE sccp_device_t *d = sccp_channel_getDevice_retained(channel);
+			if (d) {
+				sccp_indicate(d, channel, SCCP_CHANNELSTATE_ONHOOK);
+			}
 		}
-	} else {
-		pbx_log(LOG_NOTICE, "%s: (sccp_wrapper_asterisk_carefullHangup) Already Hungup. Forcing SCCP Remove Call.\n", pbx_channel_name(pbx_channel));
-		channel->hangupRequest = sccp_wrapper_asterisk_nullHangup;
-		sccp_pbx_hangup(channel);
-		res = TRUE; 
-	}
-	ast_channel_unref(pbx_channel);
-	return res;
-}
-
-boolean_t sccp_wrapper_asterisk_requestQueueHangup(sccp_channel_t *channel)
-{
-	boolean_t res = FALSE;
-	PBX_CHANNEL_TYPE *pbx_channel = channel->owner;
-
-	channel->hangupRequest = sccp_wrapper_asterisk_carefullHangup;
-	if (!ast_check_hangup(pbx_channel)) {							/* if channel is not already been hungup */
-		res = ast_queue_hangup(pbx_channel) ? FALSE : TRUE;
-	} else {
-		pbx_log(LOG_NOTICE, "%s: (sccp_wrapper_asterisk_requestQueueHangup) Already Hungup\n", channel->designator);
 	}
 	return res;
 }
 
-boolean_t sccp_wrapper_asterisk_requestHangup(sccp_channel_t *channel)
-{
-	PBX_CHANNEL_TYPE *pbx_channel = channel->owner;
-	channel->hangupRequest = sccp_wrapper_asterisk_carefullHangup;
-	if (!ast_check_hangup(pbx_channel)) {
-		ast_hangup(pbx_channel);
-	}
-	return TRUE;
-}
-
 int sccp_asterisk_pbx_fktChannelWrite(PBX_CHANNEL_TYPE * ast, const char *funcname, char *args, const char *value)
 {
 	sccp_channel_t *c;
@@ -763,6 +799,44 @@ boolean_t sccp_wrapper_asterisk_featureMonitor(const sccp_channel_t * channel)
 
 }
 
+#if !defined(AST_DEFAULT_EMULATE_DTMF_DURATION)
+#define AST_DEFAULT_EMULATE_DTMF_DURATION 100
+#endif
+#if ASTERISK_VERSION_GROUP > 106
+int sccp_wrapper_sendDigits(const sccp_channel_t * channel, const char *digits)
+{
+	if (!channel || !channel->owner) {
+		pbx_log(LOG_WARNING, "No channel to send digits to\n");
+		return 0;
+	}
+	//ast_channel_undefer_dtmf(channel->owner);
+	PBX_CHANNEL_TYPE *pbx_channel = channel->owner;
+	int i;
+	PBX_FRAME_TYPE f = ast_null_frame;
+	sccp_log((DEBUGCAT_HIGH)) (VERBOSE_PREFIX_3 "%s: Sending digits '%s'\n", (char *) channel->currentDeviceId, digits);
+	// We don't just call sccp_pbx_senddigit due to potential overhead, and issues with locking
+	f.src = "SCCP";
+	for (i = 0; digits[i] != '\0'; i++) {
+		sccp_log((DEBUGCAT_HIGH)) (VERBOSE_PREFIX_3 "%s: Sending digit %c\n", (char *) channel->currentDeviceId, digits[i]);
+
+		f.frametype = AST_FRAME_DTMF_END;								// Sending only the dmtf will force asterisk to start with DTMF_BEGIN and schedule the DTMF_END
+		f.subclass.integer = digits[i];
+//		f.len = SCCP_MIN_DTMF_DURATION;
+		f.len = AST_DEFAULT_EMULATE_DTMF_DURATION;
+		f.src = "SEND DIGIT";
+		ast_queue_frame(pbx_channel, &f);
+	}
+	return 1;
+}
+
+int sccp_wrapper_sendDigit(const sccp_channel_t * channel, const char digit)
+{
+	char digits[3] = "\0\0";
+	digits[0] = digit;
+	sccp_log((DEBUGCAT_HIGH)) (VERBOSE_PREFIX_3 "%s: got a single digit '%c' -> '%s'\n", channel->currentDeviceId, digit, digits);
+	return sccp_wrapper_sendDigits(channel, digits);
+}
+#endif
 
 static void *sccp_asterisk_doPickupThread(void *data) {
 	PBX_CHANNEL_TYPE *pbx_channel = data;
@@ -834,9 +908,7 @@ enum ast_pbx_result pbx_pbx_start (PBX_CHANNEL_TYPE *pbx_channel) {
 				channel->hangupRequest = sccp_wrapper_asterisk_requestQueueHangup;
 			} else {
 				pbx_log(LOG_NOTICE, "%s: (pbx_pbx_start) autoloop is not running anymore, dummyHangup should remain. Will already be hungup/being hungup\n", channel->designator);
-				if (!pbx_check_hangup(pbx_channel)) {
-					ast_hangup(pbx_channel);
-				}
+				res = AST_PBX_FAILED;
 			}
 		}
 		ast_channel_unlock(pbx_channel);
