@@ -8,8 +8,8 @@
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *		See the LICENSE file at the top of the source tree.
  *
- * $Date: 2014-05-30 19:56:13 +0200 (Fri, 30 May 2014) $
- * $Revision: 5449 $  
+ * $Date: 2014-07-02 19:24:24 +0200 (Wed, 02 Jul 2014) $
+ * $Revision: 5558 $  
  */
 #ifndef __SCCP_PBX_WRAPPER_H
 #define __SCCP_PBX_WRAPPER_H
@@ -372,5 +372,9 @@ void sccp_asterisk_redirectedUpdate(sccp_channel_t * channel, const void *data,
 void sccp_asterisk_sendRedirectedUpdate(const sccp_channel_t * channel, const char *fromNumber, const char *fromName, const char *toNumber, const char *toName, uint8_t reason);
 int sccp_wrapper_asterisk_channel_read(PBX_CHANNEL_TYPE * ast, NEWCONST char *funcname, char *args, char *buf, size_t buflen);
 boolean_t sccp_wrapper_asterisk_featureMonitor(const sccp_channel_t * channel);
+#if ASTERISK_VERSION_GROUP > 106
+int sccp_wrapper_sendDigits(const sccp_channel_t * channel, const char *digits);
+int sccp_wrapper_sendDigit(const sccp_channel_t * channel, const char digit);
+#endif
 enum ast_pbx_result pbx_pbx_start (struct ast_channel *ast);
 #endif
