@@ -15,8 +15,8 @@
  * Relations:	SCCP Device -> SCCP DeviceLine -> SCCP Line
  * 		SCCP Line -> SCCP ButtonConfig -> SCCP Device
  *
- * \date	$Date: 2014-06-28 18:34:10 +0200 (Sat, 28 Jun 2014) $
- * \version     $Revision: 5536 $
+ * \date	$Date: 2014-07-04 00:07:29 +0200 (Fri, 04 Jul 2014) $
+ * \version     $Revision: 5569 $
  */
 
 #include <config.h>
@@ -32,7 +32,7 @@
 #include "sccp_indicate.h"
 #include "sccp_mwi.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 5536 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5569 $")
 int __sccp_device_destroy(const void *ptr);
 void sccp_device_removeFromGlobals(sccp_device_t * device);
 int sccp_device_destroy(const void *ptr);
@@ -130,6 +130,20 @@ static void sccp_device_setBackgroundImage(const sccp_device_t * device, const c
 	device->protocol->sendUserToDeviceDataVersionMessage(device, 0, 0, 0, transactionID, xmlStr, 0);
 }
 
+static sccp_dtmfmode_t sccp_device_getDtfmMode(const sccp_device_t *device) 
+{
+	sccp_dtmfmode_t res = device->dtmfmode;
+	
+	if (device->dtmfmode == SCCP_DTMFMODE_AUTO) {
+		if ((device->device_features & SKINNY_PHONE_FEATURES_RFC2833) == SKINNY_PHONE_FEATURES_RFC2833) {
+			res = SCCP_DTMFMODE_RFC2833;	
+		} else {
+			res = SCCP_DTMFMODE_SKINNY;
+		}
+	}
+	return res;
+}
+
 static void sccp_device_setBackgroundImageNotSupported(const sccp_device_t * device, const char *url)
 {
 	sccp_log((DEBUGCAT_DEVICE)) (VERBOSE_PREFIX_3 "%s: does not support Background Image\n", device->id);
@@ -184,6 +198,8 @@ static void sccp_device_setRingtoneNotSupported(const sccp_device_t * device, co
 	sccp_log((DEBUGCAT_DEVICE)) (VERBOSE_PREFIX_3 "%s: does not support setting ringtone\n", device->id);
 }
 
+
+
 /*
 static void sccp_device_startStream(const sccp_device_t *device, const char *address, uint32_t port){
 	char xmlStr[2048];
@@ -448,6 +464,7 @@ sccp_device_t *sccp_device_create(const char *id)
 	d->displayBackgroundImagePreview = sccp_device_displayBackgroundImagePreviewNotSupported;
 	d->retrieveDeviceCapabilities = sccp_device_retrieveDeviceCapabilities;
 	d->setRingTone = sccp_device_setRingtoneNotSupported;
+	d->getDtmfMode = sccp_device_getDtfmMode;
 	d->pendingUpdate = 0;
 	d->pendingDelete = 0;
 	return d;
@@ -1774,7 +1791,7 @@ void sccp_dev_postregistration(void *data)
 	}
 	sprintf(family, "SCCP/%s", d->id);
 	if (PBX(feature_getFromDatabase) (family, "dnd", buffer, sizeof(buffer)) && strcmp(buffer, "")) {
-		sccp_config_parse_dnd(&d->dndFeature.status, sizeof(d->dndFeature.status), (const char *) buffer, SCCP_CONFIG_DEVICE_SEGMENT);
+		d->dndFeature.status = sccp_dndmode_str2val(buffer);
 		sccp_feat_changed(d, NULL, SCCP_FEATURE_DND);
 	}
 
@@ -2178,6 +2195,8 @@ int sccp_device_sendReset(sccp_device_t * d, uint8_t reset_type)
 	return 1;
 }
 
+
+
 /*!
  * \brief Send Call State to Device
  * \param d SCCP Device
@@ -2343,7 +2362,7 @@ static void sccp_device_indicate_onhook(const sccp_device_t * device, const sccp
 	if (channel && channel == device->active_channel) {
 		sccp_dev_set_speaker(device, SKINNY_STATIONSPEAKER_OFF);
 	}
-	sccp_device_clearMessageFromStack(device, SCCP_MESSAGE_PRIORITY_PRIVACY);
+	sccp_device_clearMessageFromStack((sccp_device_t *)device, SCCP_MESSAGE_PRIORITY_PRIVACY);
 	sccp_dev_check_displayprompt(device);						/* see if we need to display anything from the messageStack */
 }
 
@@ -2405,7 +2424,7 @@ static void sccp_device_indicate_proceed(const sccp_device_t * device, const uin
 /*!
  * \brief Add message to the MessageStack to be shown on the Status Line of the SCCP Device
  */
-void sccp_device_addMessageToStack(const sccp_device_t * device, const uint8_t priority, const char *message)
+void sccp_device_addMessageToStack(sccp_device_t * device, const uint8_t priority, const char *message)
 {
 	// sccp_log((DEBUGCAT_CORE + DEBUGCAT_DEVICE + DEBUGCAT_MESSAGE)) (VERBOSE_PREFIX_1 "%s: (sccp_device_addMessageToStack), '%s' at priority %d \n", DEV_ID_LOG(device), message, priority);
 	if (ARRAY_LEN(device->messageStack) <= priority) {
@@ -2429,7 +2448,7 @@ void sccp_device_addMessageToStack(const sccp_device_t * device, const uint8_t p
 /*!
  * \brief Remove a message from the MessageStack to be shown on the Status Line of the SCCP Device
  */
-void sccp_device_clearMessageFromStack(const sccp_device_t * device, const uint8_t priority)
+void sccp_device_clearMessageFromStack(sccp_device_t * device, const uint8_t priority)
 {
 	if (ARRAY_LEN(device->messageStack) <= priority) {
 		return;
