@@ -6,8 +6,8 @@
  * 		See the LICENSE file at the top of the source tree.
  * \since	2009-01-16
  *
- * $Date: 2014-06-27 15:39:53 +0200 (Fri, 27 Jun 2014) $
- * $Revision: 5531 $
+ * $Date: 2014-07-02 19:24:24 +0200 (Wed, 02 Jul 2014) $
+ * $Revision: 5558 $
  */
 
 /*!
@@ -35,7 +35,7 @@
 #include "sccp_indicate.h"
 #include "sccp_rtp.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 5531 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5558 $")
 
 /*!
  * \brief Handle Call Forwarding
@@ -1323,7 +1323,10 @@ void sccp_feat_adhocDial(sccp_device_t * d, sccp_line_t * line)
 			sccp_pbx_softswitch(c);
 			return;
 		}
-		sccp_pbx_senddigits(c, line->adhocNumber);
+		//sccp_pbx_senddigits(c, line->adhocNumber);
+                if (PBX(send_digits)) {
+                        PBX(send_digits) (c, line->adhocNumber);
+                }
 	} else {
 		// Pull up a channel
 		if (GLOB(hotline)->line) {
