@@ -11,8 +11,8 @@
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *		See the LICENSE file at the top of the source tree.
  *
- * $Date: 2014-02-25 15:51:27 +0100 (Tue, 25 Feb 2014) $
- * $Revision: 5245 $  
+ * $Date: 2014-06-28 18:41:40 +0200 (Sat, 28 Jun 2014) $
+ * $Revision: 5537 $  
  */
 
 #ifndef __SCCP_LABELS_H
@@ -214,6 +214,88 @@ static const struct skinny_label {
 };
 
 #define SKINNY_DISP_EMPTY                                		""
+
+#define SKINNY_DISP_ACCT						"\36\02"
+#define SKINNY_DISP_FLASH						"\36\03"
+#define SKINNY_DISP_LOGIN						"\36\04"
+#define SKINNY_DISP_DEVICE_IN_HOME_LOCATION				"\36\05"
+#define SKINNY_DISP_DEVICE_IN_ROAMING_LOCATION				"\36\06"
+#define SKINNY_DISP_ENTER_AUTHORIZATION_CODE				"\36\07"
+
+#define SKINNY_DISP_ENTER_CLIENT_MATTER_CODE				"\36\10"
+#define SKINNY_DISP_CALLS_AVAILABLE_FOR_PICKUP				"\36\11"
+#define SKINNY_DISP_CM_FALLBACK_SERVICE_OPERATING			"\36\12"
+#define SKINNY_DISP_MAX_PHONES_EXCEEDED					"\36\13"
+#define SKINNY_DISP_WAITING_TO_REHOME					"\36\14"
+#define SKINNY_DISP_PLEASE_END_CALL					"\36\15"
+#define SKINNY_DISP_PAGING						"\36\16"
+#define SKINNY_DISP_SELECT_LINE						"\36\17"
+
+#define SKINNY_DISP_TRANSFER_DESTINATION_IS_BUSY			"\36\20"
+#define SKINNY_DISP_SELECT_A_SERVICE					"\36\21"
+#define SKINNY_DISP_LOCAL_SERVICES					"\36\22"
+#define SKINNY_DISP_ENTER_SEARCH_CRITERIA				"\36\23"
+#define SKINNY_DISP_NIGHT_SERVICE					"\36\24"
+#define SKINNY_DISP_NIGHT_SERVICE_ACTIVE				"\36\25"
+#define SKINNY_DISP_NIGHT_SERVICE_DISABLED				"\36\26"
+#define SKINNY_DISP_LOGIN_SUCCESSFUL					"\36\27"
+
+#define SKINNY_DISP_WRONG_PIN						"\36\30"
+#define SKINNY_DISP_PLEASE_ENTER_PIN					"\36\31"
+#define SKINNY_DISP_OF							"\36\32"
+#define SKINNY_DISP_RECORDS_1_TO					"\36\33"
+#define SKINNY_DISP_NO_RECORD_FOUND					"\36\34"
+#define SKINNY_DISP_SEARCH_RESULTS					"\36\35"
+#define SKINNY_DISP_CALLS_IN_QUEUE					"\36\36"
+#define SKINNY_DISP_JOIN_TO_HUNT_GROUP					"\36\37"
+
+#define SKINNY_DISP_READY						"\36\40"
+#define SKINNY_DISP_NOTREADY						"\36\41"
+#define SKINNY_DISP_CALL_ON_HOLD					"\36\42"
+#define SKINNY_DISP_HOLD_REVERSION					"\36\43"
+#define SKINNY_DISP_SETUP_FAILED					"\36\44"
+#define SKINNY_DISP_NO_RESOURCES					"\36\45"
+#define SKINNY_DISP_DEVICE_NOT_AUTHORIZED				"\36\46"
+#define SKINNY_DISP_MONITORING						"\36\47"
+
+#define SKINNY_DISP_RECORDING_AWAITING_CALL_TO_BE_ACTIVE		"\36\50"
+#define SKINNY_DISP_RECORDING_ALREADY_IN_PROGRESS			"\36\51"
+#define SKINNY_DISP_INACTIVE_RECORDING_SESSION				"\36\52"
+#define SKINNY_DISP_MOBILITY						"\36\53"
+#define SKINNY_DISP_WHISPER						"\36\54"
+#define SKINNY_DISP_FORWARD_ALL						"\36\55"
+#define SKINNY_DISP_MALICIOUS_CALL_ID					"\36\56"
+#define SKINNY_DISP_GROUP_PICKUP					"\36\57"
+
+#define SKINNY_DISP_REMOVE_LAST_PARTICIPANT				"\36\60"
+#define SKINNY_DISP_OTHER_PICKUP					"\36\61"
+#define SKINNY_DISP_VIDEO						"\36\62"
+#define SKINNY_DISP_END_CALL						"\36\63"
+#define SKINNY_DISP_CONFERENCE_LIST					"\36\64"
+#define SKINNY_DISP_QUALITY_REPORTING_TOOL				"\36\65"
+#define SKINNY_DISP_HUNT_GROUP						"\36\66"
+#define SKINNY_DISP_USE_LINE_OR_JOIN_TO_COMPLETE			"\36\67"
+
+#define SKINNY_DISP_DO_NOT_DISTURB					"\36\70"
+#define SKINNY_DISP_DO_NOT_DISTURB_IS_ACTIVE				"\36\71"
+#define SKINNY_DISP_CFWDALL_LOOP_DETECTED				"\36\72"
+#define SKINNY_DISP_CFWDALL_HOPS_EXCEEDED				"\36\73"
+#define SKINNY_DISP_ABBRDIAL						"\36\74"
+#define SKINNY_DISP_PICKUP_IS_UNAVAILABLE				"\36\75"
+#define SKINNY_DISP_CONFERENCE_IS_UNAVAILABLE				"\36\76"
+#define SKINNY_DISP_MEETME_IS_UNAVAILABLE				"\36\77"
+
+#define SKINNY_DISP_CANNOT_RETRIEVE_PARKED_CALL				"\36\100"
+#define SKINNY_DISP_CANNOT_SEND_CALL_TO_MOBILE				"\36\101"
+#define SKINNY_DISP_RECORD						"\36\103"
+#define SKINNY_DISP_CANNOT_MOVE_CONVERSATION				"\36\104"
+#define SKINNY_DISP_CW_OFF						"\36\105"
+#define SKINNY_DISP_COACHING						"\36\106"
+#define SKINNY_DISP_RECORDING						"\36\117"
+
+#define SKINNY_DISP_RECORDING_FAILED					"\36\120"
+#define SKINNY_DISP_CONNECTING						"\36\121"
+
 #define SKINNY_DISP_REDIAL                                		"\200\1"
 #define SKINNY_DISP_NEWCALL                               		"\200\2"
 #define SKINNY_DISP_HOLD                                  		"\200\3"
@@ -316,14 +398,14 @@ static const struct skinny_label {
 #define SKINNY_DISP_MAX_CALL_DURATION_TIMEOUT				"\200\131"
 #define SKINNY_DISP_MAX_HOLD_DURATION_TIMEOUT				"\200\132"
 #define SKINNY_DISP_OPICKUP						"\200\133"
-#define SKINNY_DISP_NO_CALL_AVAILABLE_FOR_PICKUP                	"\200\137"				/*<! - FS */
-#define SKINNY_DISP_PARK_SLOT_UNAVAILABLE                       	"\200\136"				/*<! - FS */
-#define SKINNY_DISP_LOGGED_OUT_OF_HUNT_GROUP                    	"\200\135"				/*<! - FS */
 #define SKINNY_DISP_HLOG                                        	"\200\134"				/*<! - FS */
+#define SKINNY_DISP_LOGGED_OUT_OF_HUNT_GROUP                    	"\200\135"				/*<! - FS */
+#define SKINNY_DISP_PARK_SLOT_UNAVAILABLE                       	"\200\136"				/*<! - FS */
+#define SKINNY_DISP_NO_CALL_AVAILABLE_FOR_PICKUP                	"\200\137"				/*<! - FS */
 
 #define SKINNY_DISP_EXTERNAL_TRANSFER_RESTRICTED			"\200\141"
 #define SKINNY_DISP_NO_LINE_AVAILABLE_FOR_PICKUP			"\200\142"				/*<! - FS */
-#define SKINNY_DISP_UNKNOWN_1						"\200\143"
+#define SKINNY_DISP_PATH_REPLACEMENT_IN_PROGRESS			"\200\143"
 #define SKINNY_DISP_UNKNOWN_2						"\200\144"
 #define SKINNY_DISP_MAC_ADDRESS						"\200\145"
 #define SKINNY_DISP_HOST_NAME						"\200\146"
@@ -356,7 +438,25 @@ static const struct skinny_label {
 #define SKINNY_DISP_MESSAGES_URL					"\200\176"
 #define SKINNY_DISP_SERVICES_URL					"\200\177"
 
-#define SKINNY_DISP_MONITOR						"Record"
+// Need to be translated
+//#define SKINNY_DISP_MONITOR						"Record"
 #define SKINNY_DISP_DIAL						"Dial"
+#define SKINNY_DISP_CALL_PROGRESS					"Call Progress" 
+#define SKINNY_DISP_SILENT						"Silent"
+#define SKINNY_DISP_ENTER_NUMBER_TO_FORWARD_TO				"Enter number to forward to"
+
+// Errors needing to be translated
+#define SKINNY_DISP_NO_LINES_REGISTERED					"No lines registered!"
+#define SKINNY_DISP_NO_LINE_TO_TRANSFER					"No line found to transfer"
+#define SKINNY_DISP_NO_LINE_AVAILABLE					"No Line Available"
+#define SKINNY_DISP_NO_MORE_DIGITS					"No more digits"
+#define SKINNY_DISP_NO_ACTIVE_CALL_TO_PUT_ON_HOLD			"No Active call to put on hold"
+#define SKINNY_DISP_TRANSVM_WITH_NO_CHANNEL				"TRANSVM with no channel active"
+#define SKINNY_DISP_TRANSVM_WITH_NO_LINE				"TRANSVM with no line active"
+#define SKINNY_DISP_NOT_ENOUGH_CALLS_TO_TRANSFER			"Not enough calls to transfer"
+#define SKINNY_DISP_MORE_THAN_TWO_CALLS					"More that two calls"
+#define SKINNY_DISP_USE							"use"
+#define SKINNY_DISP_PRIVATE_FEATURE_NOT_ACTIVE				"Private Feature is not active"
+#define SKINNY_DISP_PRIVATE_WITHOUT_LINE_CHANNEL			"Private without line or channel"
 
 #endif
