@@ -8,8 +8,8 @@
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *		See the LICENSE file at the top of the source tree.
  *
- * $Date: 2014-06-27 15:02:23 +0200 (Fri, 27 Jun 2014) $
- * $Revision: 5530 $
+ * $Date: 2014-07-03 23:48:56 +0200 (Thu, 03 Jul 2014) $
+ * $Revision: 5568 $
  */
 
 #include <config.h>
@@ -22,7 +22,7 @@
 #include "sccp_config.h"
 #include "sccp_mwi.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 5530 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5568 $")
 static void regcontext_exten(sccp_line_t * l, struct subscriptionId *subscriptionId, int onoff);
 int __sccp_line_destroy(const void *ptr);
 int __sccp_lineDevice_destroy(const void *ptr);
@@ -598,7 +598,7 @@ void sccp_line_addChannel(sccp_line_t * line, sccp_channel_t * channel)
 		if ((c = sccp_channel_retain(channel))) {							// Add into list retained
 			sccp_channel_updateChannelDesignator(c);
 			sccp_log((DEBUGCAT_LINE)) (VERBOSE_PREFIX_1 "SCCP: Adding channel %d to line %s\n", c->callid, l->name);
-			if (GLOB(callanswerorder) == ANSWER_OLDEST_FIRST) {
+			if (GLOB(callanswerorder) == SCCP_ANSWER_OLDEST_FIRST) {
 				SCCP_LIST_INSERT_TAIL(&l->channels, c, list);					// add to list
 			} else {
 				SCCP_LIST_INSERT_HEAD(&l->channels, c, list);					// add to list
