@@ -5,8 +5,8 @@
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
  * 		See the LICENSE file at the top of the source tree.
  * 
- * $Date: 2014-06-24 13:30:45 +0200 (Tue, 24 Jun 2014) $
- * $Revision: 5512 $  
+ * $Date: 2014-07-02 12:48:06 +0200 (Wed, 02 Jul 2014) $
+ * $Revision: 5553 $  
  */
 #include <config.h>
 #ifdef CS_SCCP_MANAGER
@@ -21,7 +21,7 @@
 #include "sccp_actions.h"
 #include "sccp_socket.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 5512 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5553 $")
 
 /*
  * Descriptions
@@ -743,11 +743,11 @@ static int sccp_manager_holdCall(struct mansession *s, const struct message *m)
 	const char *hold = astman_get_header(m, "hold");
 	const char *deviceName = astman_get_header(m, "Devicename");
 	const char *swap = astman_get_header(m, "SwapChannels");
-	char *retValStr = "Channel was resumed";
+	static char *retValStr = "Channel was resumed";
 	boolean_t errorMessage = TRUE;
 
 	if (atoi(channelId)==0) {
-		snprintf(retValStr, sizeof(retValStr), "Channel Id has to be a number. You have provided: '%s'\r\n", channelId);
+		sprintf(retValStr, "Channel Id has to be a number. You have provided: '%s'\r\n", channelId);
 		astman_send_error(s, m, retValStr);
 		return 0;		
 	}
