@@ -5,8 +5,8 @@
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
  * 		See the LICENSE file at the top of the source tree.
  * 
- * $Date$
- * $Revision$  
+ * $Date: 2014-05-30 19:56:13 +0200 (Fri, 30 May 2014) $
+ * $Revision: 5449 $  
  */
 
 /*!
@@ -59,7 +59,7 @@
 #include "sccp_indicate.h"
 #include "sccp_mwi.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision$")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5449 $")
 //nb: SCCP_HASH_PRIME defined in config.h, default 536
 #define SCCP_SIMPLE_HASH(_a) (((unsigned long)(_a)) % SCCP_HASH_PRIME)
 #define SCCP_LIVE_MARKER 13
@@ -512,3 +512,15 @@ gcc_inline void sccp_refcount_replace(void **replaceptr, void *newptr, const cha
 		}
 	}
 }
+
+/*
+ * \brief refence autorelease helper
+ * Used together with the cleanup attribute, to handle the automatic reference release of an object when we leave the scope in which the 
+ * reference was defined. 
+ */
+void sccp_refcount_autorelease(void *ptr) 
+{
+	if (*(void **) ptr) {
+		sccp_refcount_release(*(void **) ptr, __FILE__, __LINE__, __PRETTY_FUNCTION__);
+	}
+}
