@@ -9,8 +9,8 @@
  * \note                This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *              See the LICENSE file at the top of the source tree.
  *
- * $Date$
- * $Revision$
+ * $Date: 2014-06-10 10:29:16 +0200 (Tue, 10 Jun 2014) $
+ * $Revision: 5493 $
  */
 
 #include <config.h>
@@ -21,7 +21,7 @@
 #include "sccp_rtp.h"
 #include "sccp_socket.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision$")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5493 $")
 
 /*!
  * \brief create a new rtp server for audio data
@@ -30,7 +30,6 @@ SCCP_FILE_VERSION(__FILE__, "$Revision$")
 int sccp_rtp_createAudioServer(const sccp_channel_t * c)
 {
 	boolean_t rtpResult = FALSE;
-	sccp_device_t *device = NULL;
 	boolean_t isMappedIPv4;
 
 	if (!c) {
@@ -54,29 +53,23 @@ int sccp_rtp_createAudioServer(const sccp_channel_t * c)
 	}
 	
 	uint16_t port = sccp_rtp_getServerPort(&c->rtp.audio);
-	pbx_log(LOG_NOTICE, "RTP Server Port: %d\n", port);
+	sccp_log(DEBUGCAT_RTP) (VERBOSE_PREFIX_3 "RTP Server Port: %d\n", port);
 
-	device = sccp_channel_getDevice_retained(c);
 	/* depeding on the client connection, we us ipv4 or ipv6*/
-	if(device){
+	AUTO_RELEASE sccp_device_t *device = sccp_channel_getDevice_retained(c);
+	if (device) {  
 		memcpy((void *)&c->rtp.audio.phone_remote, &device->session->ourip, sizeof(struct sockaddr_storage));
 		sccp_socket_setPort(&c->rtp.audio.phone_remote, port);
-	}else{
-		pbx_log(LOG_NOTICE, "no device\n");
 	}
 	
-	
 	sccp_log(DEBUGCAT_RTP) (VERBOSE_PREFIX_3 "is IPv4: %d\n", sccp_socket_is_IPv4(&c->rtp.audio.phone_remote) ? 1 : 0 );
 	sccp_log(DEBUGCAT_RTP) (VERBOSE_PREFIX_3 "is IPv6: %d\n", sccp_socket_is_IPv6(&c->rtp.audio.phone_remote) ? 1 : 0 );
 	
-	
 	isMappedIPv4 = sccp_socket_ipv4_mapped(&c->rtp.audio.phone_remote, (struct sockaddr_storage *)&c->rtp.audio.phone_remote);		/*!< this is absolute necessary */
 	sccp_log(DEBUGCAT_RTP) (VERBOSE_PREFIX_3 "is mapped: %d\n", isMappedIPv4 ? 1 : 0 );
 	
-	
 	//struct sockaddr_in us;
 	//      PBX(rtp_setPeer) (&c->rtp.audio, &c->rtp.audio.phone, device ? device->nat : 0);
-	device = device ? sccp_device_release(device) : NULL;
 
 	return rtpResult;
 }
@@ -173,15 +166,14 @@ void sccp_rtp_set_peer(sccp_channel_t * c, struct sccp_rtp *rtp, struct sockaddr
  */
 void sccp_rtp_set_phone(sccp_channel_t * c, struct sccp_rtp *rtp, struct sockaddr_storage *new_peer)
 {
-	sccp_device_t *device;
-
 	/* validate socket */
 	if ( sccp_socket_getPort(new_peer) == 0) {
 		sccp_log((DEBUGCAT_RTP)) (VERBOSE_PREFIX_2 "%s: (sccp_rtp_set_phone) remote information are invalid, dont change anything\n", c->currentDeviceId);
 		return;
 	}
 
-	if ((device = sccp_channel_getDevice_retained(c))) {
+	AUTO_RELEASE sccp_device_t *device = sccp_channel_getDevice_retained(c);
+	if (device) {
 
 		/* check if we have new infos */
 		/*! \todo if we enable this, we get an audio issue when resume on the same device, so we need to force asterisk to update -MC */
@@ -204,8 +196,6 @@ void sccp_rtp_set_phone(sccp_channel_t * c, struct sccp_rtp *rtp, struct sockadd
                 char buf2[NI_MAXHOST + NI_MAXSERV];
                 sccp_copy_string(buf2, sccp_socket_stringify(&rtp->phone), sizeof(buf2));
 		sccp_log(DEBUGCAT_RTP) (VERBOSE_PREFIX_3 "%s: Tell PBX   to send RTP/UDP media from %s to %s (NAT: %s)\n", DEV_ID_LOG(device), buf1, buf2, device->nat ? "yes" : "no");
-
-		device = sccp_device_release(device);
 	}
 }
 
@@ -214,10 +204,9 @@ void sccp_rtp_set_phone(sccp_channel_t * c, struct sccp_rtp *rtp, struct sockadd
  */
 sccp_rtp_info_t sccp_rtp_getAudioPeerInfo(const sccp_channel_t * c, struct sccp_rtp **rtp)
 {
-	sccp_device_t *device = NULL;
 	sccp_rtp_info_t result = SCCP_RTP_INFO_NORTP;
 
-	device = sccp_channel_getDevice_retained(c);
+	AUTO_RELEASE sccp_device_t *device = sccp_channel_getDevice_retained(c);
 	if (!device) {
 		return SCCP_RTP_INFO_NORTP;
 	}
@@ -229,8 +218,6 @@ sccp_rtp_info_t sccp_rtp_getAudioPeerInfo(const sccp_channel_t * c, struct sccp_
 	if (device->directrtp && !device->nat && !c->conference) {
 		result |= SCCP_RTP_INFO_ALLOW_DIRECTRTP;
 	}
-
-	device = device ? sccp_device_release(device) : NULL;
 	return result;
 }
 
@@ -240,9 +227,8 @@ sccp_rtp_info_t sccp_rtp_getAudioPeerInfo(const sccp_channel_t * c, struct sccp_
 sccp_rtp_info_t sccp_rtp_getVideoPeerInfo(const sccp_channel_t * c, struct sccp_rtp ** rtp)
 {
 	sccp_rtp_info_t result = SCCP_RTP_INFO_NORTP;
-	sccp_device_t *device = NULL;
 
-	device = sccp_channel_getDevice_retained(c);
+	AUTO_RELEASE sccp_device_t *device = sccp_channel_getDevice_retained(c);
 	if (!device) {
 		return SCCP_RTP_INFO_NORTP;
 	}
@@ -253,8 +239,6 @@ sccp_rtp_info_t sccp_rtp_getVideoPeerInfo(const sccp_channel_t * c, struct sccp_
 	if (device->directrtp && !device->nat && !c->conference) {
 		result |= SCCP_RTP_INFO_ALLOW_DIRECTRTP;
 	}
-
-	device = device ? sccp_device_release(device) : NULL;
 	return result;
 }
 
@@ -288,10 +272,7 @@ int sccp_rtp_get_sampleRate(skinny_codec_t codec)
  */
 void sccp_rtp_destroy(sccp_channel_t * c)
 {
-	sccp_line_t *l = NULL;
-
-	l = c->line;
-
+	sccp_line_t *l = c->line;
 	if (c->rtp.audio.rtp) {
 		sccp_log(DEBUGCAT_RTP) (VERBOSE_PREFIX_3 "%s: destroying PBX rtp server on channel %s-%08X\n", c->currentDeviceId, l ? l->name : "(null)", c->callid);
 		PBX(rtp_destroy) (c->rtp.audio.rtp);
@@ -338,12 +319,12 @@ boolean_t sccp_rtp_getUs(const struct sccp_rtp *rtp, struct sockaddr_storage *us
 }
 
 uint16_t sccp_rtp_getServerPort(const struct sccp_rtp *rtp){
-    uint16_t port = 0;
-    struct sockaddr_storage sas;
-    sccp_rtp_getUs(rtp, &sas);
-    
-    port = sccp_socket_getPort(&sas);
-    return port;
+	uint16_t port = 0;
+	struct sockaddr_storage sas;
+	sccp_rtp_getUs(rtp, &sas);
+
+	port = sccp_socket_getPort(&sas);
+	return port;
 }
 
 /*!
