@@ -8,8 +8,8 @@
  * \note                This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *              See the LICENSE file at the top of the source tree.
  *
- * $Date: 2014-06-27 15:02:23 +0200 (Fri, 27 Jun 2014) $
- * $Revision: 5530 $
+ * $Date: 2014-07-03 23:41:19 +0200 (Thu, 03 Jul 2014) $
+ * $Revision: 5566 $
  */
 
 #include <netinet/in.h>
@@ -19,7 +19,7 @@
 #include "sccp_device.h"
 #include "sccp_utils.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 5530 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5566 $")
 #ifndef CS_USE_POLL_COMPAT
 #include <poll.h>
 #include <sys/poll.h>
@@ -997,7 +997,7 @@ void *sccp_socket_thread(void *ignore)
 		} else if (res == 0) {
 			// poll timeout
 		} else {
-			if (GLOB(module_running)) {
+			if (GLOB(module_running) && !GLOB(reload_in_progress)) {
 				sccp_log((DEBUGCAT_SOCKET)) (VERBOSE_PREFIX_3 "SCCP: Accept Connection\n");
 				sccp_accept_connection();
 			}
