@@ -9,8 +9,8 @@
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *		See the LICENSE file at the top of the source tree.
  *
- * $Date: 2014-06-27 15:39:53 +0200 (Fri, 27 Jun 2014) $
- * $Revision: 5531 $
+ * $Date: 2014-07-02 14:34:16 +0200 (Wed, 02 Jul 2014) $
+ * $Revision: 5556 $
  */
 
 #include <config.h>
@@ -19,13 +19,14 @@
 #include "sccp_pbx.h"
 #include "sccp_device.h"
 #include "sccp_channel.h"
+#include "sccp_indicate.h"
 #include "sccp_line.h"
 #include "sccp_utils.h"
 #include "sccp_features.h"
 #include "sccp_actions.h"
 #include "sccp_rtp.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 5531 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5556 $")
 
 /* private prototypes */
 void sccp_sk_videomode(sccp_device_t * d, sccp_line_t * l, const uint32_t lineInstance, sccp_channel_t * c);
@@ -408,17 +409,25 @@ void sccp_sk_endcall(sccp_device_t * d, sccp_line_t * l, const uint32_t lineInst
 {
 	sccp_log((DEBUGCAT_SOFTKEY)) (VERBOSE_PREFIX_3 "%s: SoftKey EndCall Pressed\n", DEV_ID_LOG(d));
 	if (!c) {
-		sccp_log((DEBUGCAT_SOFTKEY)) (VERBOSE_PREFIX_3 "%s: Endcall with no call in progress\n", d->id);
+		pbx_log(LOG_NOTICE, "%s: Endcall with no call in progress\n", d->id);
 		return;
 	}
 	
-	if (c->calltype == SKINNY_CALLTYPE_INBOUND && 1 < c->subscribers--) { // && pbx_channel_state(c->owner) != AST_STATE_UP) {
-		if (d && d->indicate && d->indicate->onhook) {
-			d->indicate->onhook(d, c, lineInstance, c->callid);
-		}
-	} else {
+//	if (c->calltype == SKINNY_CALLTYPE_INBOUND && 1 < c->subscribers--) { // && pbx_channel_state(c->owner) != AST_STATE_UP) {
+//		if (d && d->indicate && d->indicate->onhook) {
+//			d->indicate->onhook(d, c, lineInstance, c->callid);
+//		}
+//	} else {
+//		sccp_channel_endcall(c);
+//	}
+
+	if (!(c->calltype == SKINNY_CALLTYPE_INBOUND && 1 < c->subscribers--)) {
 		sccp_channel_endcall(c);
 	}
+	if (d && d->indicate && d->indicate->onhook) {
+		sccp_indicate(d, c, SCCP_CHANNELSTATE_ONHOOK);
+		//d->indicate->onhook(d, c, lineInstance, c->callid);
+	}
 }
 
 /*!
